durationtools.group_duration_tokens_by_implied_prolation
========================================================

.. autofunction:: abjad.tools.durationtools.group_duration_tokens_by_implied_prolation.group_duration_tokens_by_implied_prolation
